@@ -57,9 +57,9 @@ class PyTorchDataset(_ContinuumDataset):
     """
 
     # TODO: some datasets have a different structure, like SVHN for ex. Handle it.
-    def __init__(self, *args, dataset_type, train: bool, **kwargs):
-        super(PyTorchDataset, self).__init__(*args, train, **kwargs)
-        
+    def __init__(self, *args, dataset_type, data_path: str = "", train: bool, **kwargs):
+        super().__init__(*args, data_path, train, **kwargs)
+
         self.dataset_type = dataset_type
         self.dataset = self.dataset_type(self.data_path, download=self.download, train=self.train)
 
@@ -78,14 +78,14 @@ class InMemoryDataset(_ContinuumDataset):
     """
 
     def __init__(
-            self,
-            x_: np.ndarray,
-            y_: np.ndarray,
-            t_: Union[None, np.ndarray] = None,
-            data_type: str = "image_array",
-            **kwargs
+        self,
+        x_: np.ndarray,
+        y_: np.ndarray,
+        t_: Union[None, np.ndarray] = None,
+        data_type: str = "image_array",
+        **kwargs
     ):
-        super(InMemoryDataset, self).__init__(**kwargs)
+        super().__init__(**kwargs)
 
         assert x_.shape[0] == y_.shape[0]
         self.data = (x_, y_, t_)
@@ -112,10 +112,10 @@ class ImageFolderDataset(_ContinuumDataset):
     :param download: Dummy parameter.
     """
 
-    def __init__(self, data_folder: str, train: bool, download: bool = True, **kwargs):
-        super(ImageFolderDataset, self).__init__(download=download, **kwargs)
-
+    def __init__(self, data_folder: str, train: bool = True, download: bool = True, **kwargs):
         self.data_folder = data_folder
+        super().__init__(train=train, download=download, **kwargs)
+
         self.dataset = torchdata.ImageFolder(data_folder)
 
     @property
