@@ -1,5 +1,4 @@
 import os
-import tarfile
 import urllib.request
 import zipfile
 
@@ -23,14 +22,9 @@ def download(url, path):
 
 def unzip(path):
     directory_path = os.path.dirname(path)
-    with zipfile.ZipFile(path, 'r') as f:
-        f.extractall(directory_path)
 
-
-def untar(path):
-    directory_path = os.path.dirname(path)
-    with tarfile.open(path) as f:
-        f.extractall(directory_path)
+    with zipfile.ZipFile(path, 'r') as zip_ref:
+        zip_ref.extractall(directory_path)
 
 
 class ProgressBar:
