@@ -6,13 +6,14 @@ from continuum.datasets import MNIST
 from continuum.scenarios import Rotations
 from continuum.scenarios import Permutations
 from continuum.scenarios import ClassIncremental
+from continuum.datasets import MNISTFellowship
 
 '''
 Test the visualization with three tasks for rotations tasks
 '''
 @pytest.mark.slow
 def test_visualization_rotations():
-    clloader = Rotations(cl_dataset=MNIST("./pytest/Samples/Datasets", download=True, train=True),
+    clloader = Rotations(cl_dataset=MNIST(data_path="./pytest/Samples/Datasets", download=True, train=True),
                          nb_tasks=3,
                          list_degrees=[0, 45, 92])
 
@@ -32,7 +33,7 @@ Test the visualization with three tasks for permutations tasks
 '''
 @pytest.mark.slow
 def test_visualization_permutations():
-    clloader = Permutations(cl_dataset=MNIST("./pytest/Samples/Datasets", download=True, train=True),
+    clloader = Permutations(cl_dataset=MNIST(data_path="./pytest/Samples/Datasets", download=True, train=True),
                             nb_tasks=3,
                             seed=0)
 
@@ -51,7 +52,7 @@ Test the visualization with three tasks for incremental tasks
 '''
 @pytest.mark.slow
 def test_visualization_incremental():
-    clloader = ClassIncremental(cl_dataset=MNIST("./pytest/Samples/Datasets", download=True, train=True),
+    clloader = ClassIncremental(cl_dataset=MNIST(data_path="./pytest/Samples/Datasets", download=True, train=True),
                                 nb_tasks=5,
                                 increment=2)
 
@@ -64,3 +65,23 @@ def test_visualization_incremental():
                            title="MNIST_Incremental_{}.jpg".format(task_id),
                            nb_samples=100,
                            shape=[28, 28, 1])
+
+'''
+Test the visualization with three tasks for incremental tasks
+'''
+@pytest.mark.slow
+def test_visualization_MNISTFellowship():
+
+    cl_dataset = MNISTFellowship(data_path="./pytest/Samples/Datasets", download=True, train=True)
+    clloader = ClassIncremental(cl_dataset=cl_dataset,
+                                increment=10)
+
+    folder = "./tests/Samples/MNISTFellowship/"
+    if not os.path.exists(folder):
+        os.makedirs(folder)
+
+    for task_id, train_dataset in enumerate(clloader):
+        train_dataset.plot(path=folder,
+                           title="MNISTFellowship_Incremental_{}.jpg".format(task_id),
+                           nb_samples=100,
+                           shape=[28, 28, 1])
\ No newline at end of file
